@@ -5,7 +5,7 @@ use v5.10.0;  # recursive regex subgroups
 
 use Exporter 5.57 qw(import);
 
-our $VERSION = '0.000004';
+our $VERSION = '0.06';
 
 our @EXPORT_OK = qw(
     $URL_SEARCH_RE
@@ -23,7 +23,7 @@ our $URL_SEARCH_RE = do {
     }xms;
 
     my $protocol = qr{
-        (?: [Hh][Tt] | [Ff] ) [Tt][Pp] [Ss]?
+        [Hh][Tt][Tt][Pp] [Ss]?
     }xms;
 
     my $unreserved_subdelims_colon = qr{
@@ -124,7 +124,7 @@ our $URL_SEARCH_RE = do {
     my $query = qr{
         (
             (?:
-                [a-zA-Z0-9\-._~!\$&'*+,;=:\@/?]
+                [a-zA-Z0-9\-._~!\$&'*+,;=:\@/?\\{}]
             |
                 $pct_enc
             |
@@ -140,10 +140,8 @@ our $URL_SEARCH_RE = do {
     my $fragment = $query;
 
     qr{
-        (?:
-            $protocol ://
-            (?: $userinfo \@ )?
-        )
+        $protocol ://
+        (?: $userinfo \@ )?
         $host (?: : [0-9]+ )?
         $path?
         (?: \? $query )?
@@ -181,12 +179,16 @@ __END__
 
 =encoding utf8
 
+=for github-markdown [![Coverage Status](https://coveralls.io/repos/github/mauke/URL-Search/badge.svg?branch=main)](https://coveralls.io/github/mauke/URL-Search?branch=main)
+
 =head1 NAME
 
 URL::Search - search for URLs in plain text
 
 =head1 SYNOPSIS
 
+=for highlighter language=perl
+
   use URL::Search qw( $URL_SEARCH_RE extract_urls partition_urls );
 
   if ($text =~ /($URL_SEARCH_RE)/) {
@@ -205,15 +207,19 @@ request) the following entities:
 This variable is the core of this module. It contains a regex that matches a URL.
 
 NOTE: This regex uses capturing groups internally, so if you embed it in a
-bigger pattern, the numbering of any following capture groups will be off.
+bigger pattern, the numbering of any following capture groups will be off. If
+this is an issue, use named capture groups of the form C<< (?<NAME>...) >>
+instead. See L<perlre/Capture groups>.
 
-It only matches URLs with an explicit schema (one of C<http>, C<https>, C<ftp>,
-C<ftps>). The pattern is deliberately not anchored at the beginning, i.e. it
-will match C<http://foo> in C<"click herehttp://foo">. If you don't want that,
-use C</\b$URL_SEARCH_RE/>.
+It only matches URLs with an explicit schema (one of C<http> or C<https>). The
+pattern is deliberately not anchored at the beginning, i.e. it will match
+C<http://foo> in C<"click herehttp://foo">. If you don't want that, use
+C</\b$URL_SEARCH_RE/>.
 
 It tries to exclude artifacts of the surrounding text:
 
+=for highlighter
+
   Is mayonnaise an instrument? (https://en.wikipedia.org/wiki/Instrument,
   https://en.wikipedia.org/wiki/Mayonnaise_(instrument))
 
@@ -236,6 +242,8 @@ It uses L<C<$URL_SEARCH_RE>|/C<$URL_SEARCH_RE>> to find matches.
 
 Example:
 
+=for highlighter language=perl
+
   my $text = 'Visit us at http://html5zombo.com. Also, https://archive.org';
   my @urls = extract_urls $text;
   # @urls = ('http://html5zombo.com', 'https://archive.org')
@@ -282,16 +290,58 @@ hyperlink all embedded URLs:
   }
   # result is in $html
 
+=begin :README
+
+=head1 INSTALLATION
+
+To download and install this module, use your favorite CPAN client, e.g.
+L<C<cpan>|cpan>:
+
+=for highlighter language=sh
+
+    cpan URL::Search
+
+Or L<C<cpanm>|cpanm>:
+
+    cpanm URL::Search
+
+To do it manually, run the following commands (after downloading and unpacking
+the tarball):
+
+    perl Makefile.PL
+    make
+    make test
+    make install
+
+=end :README
+
+=head1 SUPPORT AND DOCUMENTATION
+
+After installing, you can find documentation for this module with the
+L<C<perldoc>|perldoc> command.
+
+=for highlighter language=sh
+
+    perldoc URL::Search
+
+You can also look for information at L<https://metacpan.org/pod/URL::Search>.
+
+To see a list of open bugs, visit
+L<https://rt.cpan.org/Dist/Display.html?Name=URL-Search>.
+
+To report a new bug, send an email to
+C<bug-URL-Search [at] rt.cpan.org>.
+
 =head1 AUTHOR
 
 Lukas Mai, C<< <l.mai at web.de> >>
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright 2016 Lukas Mai.
+Copyright 2016, 2017, 2023 Lukas Mai.
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of either: the GNU General Public License as published
 by the Free Software Foundation; or the Artistic License.
 
-See L<http://dev.perl.org/licenses/> for more information.
+See L<https://dev.perl.org/licenses/> for more information.
